@@ -804,10 +804,6 @@ def given(
     """
 
     def run_test_with_generator(test):
-        if hasattr(test, "_hypothesis_internal_test_function_without_warning"):
-            # Pull out the original test function to avoid the warning we
-            # stuck in about using @settings without @given.
-            test = test._hypothesis_internal_test_function_without_warning
         if inspect.isclass(test):
             # Provide a meaningful error to users, instead of exceptions from
             # internals that assume we're dealing with a function.
