@@ -17,7 +17,6 @@
 
 from __future__ import absolute_import, division, print_function
 
-from collections import Iterable, OrderedDict
 from copy import copy
 
 import attr
@@ -29,7 +28,7 @@ import hypothesis.extra.numpy as npst
 import hypothesis.internal.conjecture.utils as cu
 from hypothesis.control import reject
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import hrange
+from hypothesis.internal.compat import OrderedDict, abc, hrange
 from hypothesis.internal.coverage import check, check_function
 from hypothesis.internal.validation import (
     check_type,
@@ -49,7 +48,7 @@ except ImportError:  # pragma: no cover
 
 
 if False:
-    from typing import Any, Union, Sequence, Set  # noqa
+    from typing import Any, List, Union, Sequence, Set  # noqa
     from hypothesis.searchstrategy.strategies import Ex  # noqa
 
 
@@ -342,6 +341,7 @@ def columns(
     fill=None,  # type: st.SearchStrategy[Ex]
     unique=False,  # type: bool
 ):
+    # type: (...) -> List[column]
     """A convenience function for producing a list of :class:`column` objects
     of the same general shape.
 
@@ -489,7 +489,7 @@ def data_frames(
                 @check_function
                 def row():
                     result = draw(rows)
-                    check_type(Iterable, result, "draw(row)")
+                    check_type(abc.Iterable, result, "draw(row)")
                     return result
 
                 if len(index) > 0:
